@@ -14,7 +14,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, Union, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -54,7 +54,7 @@ __all__ = ("DataPipelineClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -70,7 +70,7 @@ class Exceptions:
 
 class DataPipelineClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html)
     """
 
@@ -86,21 +86,21 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        parameterValues: List["ParameterValueTypeDef"] = None,
+        parameterValues: Sequence["ParameterValueTypeDef"] = None,
         startTimestamp: Union[datetime, str] = None
     ) -> Dict[str, Any]:
         """
         Validates the specified pipeline and starts processing pipeline tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.activate_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#activate_pipeline)
         """
 
-    def add_tags(self, *, pipelineId: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def add_tags(self, *, pipelineId: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds or modifies tags for the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#add_tags)
         """
 
@@ -108,17 +108,22 @@ class DataPipelineClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#can_paginate)
         """
 
     def create_pipeline(
-        self, *, name: str, uniqueId: str, description: str = None, tags: List["TagTypeDef"] = None
+        self,
+        *,
+        name: str,
+        uniqueId: str,
+        description: str = None,
+        tags: Sequence["TagTypeDef"] = None
     ) -> CreatePipelineOutputTypeDef:
         """
         Creates a new, empty pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#create_pipeline)
         """
 
@@ -126,7 +131,7 @@ class DataPipelineClient(BaseClient):
         """
         Deactivates the specified running pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.deactivate_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#deactivate_pipeline)
         """
 
@@ -134,7 +139,7 @@ class DataPipelineClient(BaseClient):
         """
         Deletes a pipeline, its pipeline definition, and its run history.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#delete_pipeline)
         """
 
@@ -142,22 +147,22 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        objectIds: List[str],
+        objectIds: Sequence[str],
         evaluateExpressions: bool = None,
         marker: str = None
     ) -> DescribeObjectsOutputTypeDef:
         """
         Gets the object definitions for a set of objects associated with the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.describe_objects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#describe_objects)
         """
 
-    def describe_pipelines(self, *, pipelineIds: List[str]) -> DescribePipelinesOutputTypeDef:
+    def describe_pipelines(self, *, pipelineIds: Sequence[str]) -> DescribePipelinesOutputTypeDef:
         """
         Retrieves metadata about one or more pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.describe_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#describe_pipelines)
         """
 
@@ -168,21 +173,21 @@ class DataPipelineClient(BaseClient):
         Task runners call `EvaluateExpression` to evaluate a string in the context of
         the specified object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.evaluate_expression)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#evaluate_expression)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#generate_presigned_url)
         """
 
@@ -192,7 +197,7 @@ class DataPipelineClient(BaseClient):
         """
         Gets the definition of the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.get_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#get_pipeline_definition)
         """
 
@@ -201,7 +206,7 @@ class DataPipelineClient(BaseClient):
         Lists the pipeline identifiers for all active pipelines that you have permission
         to access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#list_pipelines)
         """
 
@@ -216,7 +221,7 @@ class DataPipelineClient(BaseClient):
         Task runners call `PollForTask` to receive a task to perform from AWS Data
         Pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.poll_for_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#poll_for_task)
         """
 
@@ -224,14 +229,14 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        pipelineObjects: List["PipelineObjectTypeDef"],
-        parameterObjects: List["ParameterObjectTypeDef"] = None,
-        parameterValues: List["ParameterValueTypeDef"] = None
+        pipelineObjects: Sequence["PipelineObjectTypeDef"],
+        parameterObjects: Sequence["ParameterObjectTypeDef"] = None,
+        parameterValues: Sequence["ParameterValueTypeDef"] = None
     ) -> PutPipelineDefinitionOutputTypeDef:
         """
         Adds tasks, schedules, and preconditions to the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.put_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#put_pipeline_definition)
         """
 
@@ -248,26 +253,26 @@ class DataPipelineClient(BaseClient):
         Queries the specified pipeline for the names of objects that match the specified
         set of conditions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.query_objects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#query_objects)
         """
 
-    def remove_tags(self, *, pipelineId: str, tagKeys: List[str]) -> Dict[str, Any]:
+    def remove_tags(self, *, pipelineId: str, tagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes existing tags from the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#remove_tags)
         """
 
     def report_task_progress(
-        self, *, taskId: str, fields: List["FieldTypeDef"] = None
+        self, *, taskId: str, fields: Sequence["FieldTypeDef"] = None
     ) -> ReportTaskProgressOutputTypeDef:
         """
         Task runners call `ReportTaskProgress` when assigned a task to acknowledge that
         it has the task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.report_task_progress)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#report_task_progress)
         """
 
@@ -278,16 +283,16 @@ class DataPipelineClient(BaseClient):
         Task runners call `ReportTaskRunnerHeartbeat` every 15 minutes to indicate that
         they are operational.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.report_task_runner_heartbeat)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#report_task_runner_heartbeat)
         """
 
-    def set_status(self, *, pipelineId: str, objectIds: List[str], status: str) -> None:
+    def set_status(self, *, pipelineId: str, objectIds: Sequence[str], status: str) -> None:
         """
         Requests that the status of the specified physical or logical pipeline objects
         be updated in the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.set_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.set_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#set_status)
         """
 
@@ -304,7 +309,7 @@ class DataPipelineClient(BaseClient):
         Task runners call `SetTaskStatus` to notify AWS Data Pipeline that a task is
         completed and provide information about the final status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.set_task_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#set_task_status)
         """
 
@@ -312,15 +317,15 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        pipelineObjects: List["PipelineObjectTypeDef"],
-        parameterObjects: List["ParameterObjectTypeDef"] = None,
-        parameterValues: List["ParameterValueTypeDef"] = None
+        pipelineObjects: Sequence["PipelineObjectTypeDef"],
+        parameterObjects: Sequence["ParameterObjectTypeDef"] = None,
+        parameterValues: Sequence["ParameterValueTypeDef"] = None
     ) -> ValidatePipelineDefinitionOutputTypeDef:
         """
         Validates the specified pipeline definition to ensure that it is well formed and
         can be run without error.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Client.validate_pipeline_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client.html#validate_pipeline_definition)
         """
 
@@ -329,20 +334,20 @@ class DataPipelineClient(BaseClient):
         self, operation_name: Literal["describe_objects"]
     ) -> DescribeObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#describeobjectspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["query_objects"]) -> QueryObjectsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#queryobjectspaginator)
         """
