@@ -22,7 +22,7 @@ Usage::
     query_objects_paginator: QueryObjectsPaginator = client.get_paginator("query_objects")
     ```
 """
-from typing import Generic, Iterator, List, TypeVar
+from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
@@ -50,7 +50,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeObjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#describeobjectspaginator)
     """
 
@@ -58,19 +58,19 @@ class DescribeObjectsPaginator(Boto3Paginator):
         self,
         *,
         pipelineId: str,
-        objectIds: List[str],
+        objectIds: Sequence[str],
         evaluateExpressions: bool = None,
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[DescribeObjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.DescribeObjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#describeobjectspaginator)
         """
 
 
 class ListPipelinesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#listpipelinespaginator)
     """
 
@@ -78,14 +78,14 @@ class ListPipelinesPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[ListPipelinesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.ListPipelines.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#listpipelinespaginator)
         """
 
 
 class QueryObjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#queryobjectspaginator)
     """
 
@@ -98,6 +98,6 @@ class QueryObjectsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None
     ) -> _PageIterator[QueryObjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/datapipeline.html#DataPipeline.Paginator.QueryObjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/paginators.html#queryobjectspaginator)
         """
